# 2DD01.mod		
# Original AMPL coding by Alexey Izmailov 05.04.10.

# Chain problem

# Ref.: Gilbert, Practical exercises for students.
# Ref.: Bonnans and Shapiro, SIAM Rev. 40 (1998), 228264, Section 2.
# Ref.: Bonnans and Shapiro, Perturbation Analysis of Optimization Problems (2000), Section 5.2.7.
# Ref.: Arutyunov and Izmailov, MP 100 (2004), 485515, Section 6.

# Number of variables: 2m
# Number of constraints: m + 2

param m integer; # Number of bars
param sigma1 integer; # First coordinate of the second endpoint
param sigma2 integer; # Second coordinate of the second endpoint

set bars := 1..m;
param alpha {i in bars} := m - i + 1/2;

# Solution: (1, ..., 1, 0, ..., 0) for sigma1 = 0, sigma2 = m (horizontal chain)
#                  (0, ..., 0, 1, ..., 1) for sigma1 = m, sigma2 = 0 (vertical chain)
# Optimal value: 0 for sigma1 = 0, sigma2 = m (horizontal chain)
#                           m^2/2 for sigma1 = m, sigma2 = 0 (vertical chain)
# No multipliers for sigma1 = 0, sigma2 = m (horizontal chain)
# Critical multipliers for sigma1 = m, sigma2 = 0 (vertical chain): lambda[i] = -(lambda2+alpha[i])/2, alpha[i] = m - i - 1/2, i  = 1, ..., m, 
#                                                                                                             lambda1 = 0, sum_{i=1}^m 1/(lambda2 + alpha[i]) = 0

param RangeStartingPoints := 1;

option randseed 0;

var u{1..m} := Uniform(-RangeStartingPoints,RangeStartingPoints);
var v{1..m} := Uniform(-RangeStartingPoints,RangeStartingPoints);

minimize f:
         sum {i in bars} alpha[i]*v[i];

s.t. lambda{i in bars} := Uniform(-RangeStartingPoints,RangeStartingPoints):
     -u[i]^2 - v[i]^2 = -1;
s.t. lambda1 := Uniform(-RangeStartingPoints,RangeStartingPoints):
    -sum {i in bars} u[i]  = -sigma1;
s.t. lambda2 := Uniform(-RangeStartingPoints,RangeStartingPoints):
     -sum {i in bars} v[i]  = -sigma2;